================
PythonTemplateIt
================

+-----------+------------------------------------------------------------------------------------+
|**General**| |maintenance_y| |semver| |license|                                                 |
+-----------+------------------------------------------------------------------------------------+
|**CD/CI**     | |codestyle| |codecov|                                                           |
+-----------+------------------------------------------------------------------------------------+
|**PyPI**   | |pypi_release| |pypi_py_versions| |pypi_status| |pypi_format| |pypi_downloads|     |
+-----------+------------------------------------------------------------------------------------+
|**Github** | |gh_issues| |gh_language| |gh_last_commit|                                         |
+-----------+------------------------------------------------------------------------------------+


    Python repository template.


.. General

.. |maintenance_n| image:: https://img.shields.io/badge/Maintenance%20Intended-✖-red.svg?style=flat-square
    :target: http://unmaintained.tech/
    :alt: Maintenance - not intended

.. |maintenance_y| image:: https://img.shields.io/badge/Maintenance%20Intended-✔-green.svg?style=flat-square
    :target: http://unmaintained.tech/
    :alt: Maintenance - intended

.. |license| image:: https://img.shields.io/pypi/l/PythonTemplateIt
    :target: https://github.com/BrightEdgeeServices/PythonTemplateIt/blob/master/LICENSE
    :alt: License

.. |semver| image:: https://img.shields.io/badge/Semantic%20Versioning-2.0.0-brightgreen.svg?style=flat-square
    :target: https://semver.org/
    :alt: Semantic Versioning - 2.0.0


.. CI

.. |codestyle| image:: https://img.shields.io/badge/code%20style-black-000000.svg
    :target: https://github.com/psf/black
    :alt: Code Style Black

.. |pre_commit_ci| image:: https://img.shields.io/github/actions/workflow/status/BrightEdgeeServices/PythonTemplateIt/pre-commit.yml?label=pre-commit
    :target: https://github.com/BrightEdgeeServices/PythonTemplateIt/blob/master/.github/workflows/pre-commit.yml
    :alt: Pre-Commit

.. |gha_tests| image:: https://img.shields.io/github/actions/workflow/status/BrightEdgeeServices/PythonTemplateIt/ci.yml?label=ci
    :target: https://github.com/BrightEdgeeServices/PythonTemplateIt/blob/master/.github/workflows/ci.yml
    :alt: Test status

.. |gha_docu| image:: https://img.shields.io/readthedocs/PythonTemplateIt
    :target: https://github.com/BrightEdgeeServices/PythonTemplateIt/blob/master/.github/workflows/check-rst-documentation.yml
    :alt: Read the Docs

.. |codecov| image:: https://img.shields.io/codecov/c/gh/BrightEdgeeServices/PythonTemplateIt
    :target: https://app.codecov.io/gh/BrightEdgeeServices/PythonTemplateIt
    :alt: CodeCov


.. PyPI

.. |pypi_release| image:: https://img.shields.io/pypi/v/PythonTemplateIt
    :target: https://pypi.org/project/PythonTemplateIt/
    :alt: PyPI - Package latest release

.. |pypi_py_versions| image:: https://img.shields.io/pypi/pyversions/PythonTemplateIt
    :target: https://pypi.org/project/PythonTemplateIt/
    :alt: PyPI - Supported Python Versions

.. |pypi_format| image:: https://img.shields.io/pypi/wheel/PythonTemplateIt
    :target: https://pypi.org/project/PythonTemplateIt/
    :alt: PyPI - Format

.. |pypi_downloads| image:: https://img.shields.io/pypi/dm/PythonTemplateIt
    :target: https://pypi.org/project/PythonTemplateIt/
    :alt: PyPI - Monthly downloads

.. |pypi_status| image:: https://img.shields.io/pypi/status/PythonTemplateIt
    :target: https://pypi.org/project/PythonTemplateIt/
    :alt: PyPI - Status


.. GitHub

.. |gh_issues| image:: https://img.shields.io/github/issues-raw/BrightEdgeeServices/PythonTemplateIt
    :target: https://github.com/BrightEdgeeServices/PythonTemplateIt/issues
    :alt: GitHub - Issue Counter

.. |gh_language| image:: https://img.shields.io/github/languages/top/BrightEdgeeServices/PythonTemplateIt
    :target: https://github.com/BrightEdgeeServices/PythonTemplateIt
    :alt: GitHub - Top Language

.. |gh_last_commit| image:: https://img.shields.io/github/last-commit/BrightEdgeeServices/PythonTemplateIt/master
    :target: https://github.com/BrightEdgeeServices/PythonTemplateIt/commit/master
    :alt: GitHub - Last Commit

.. |gh_deployment| image:: https://img.shields.io/github/deployments/BrightEdgeeServices/PythonTemplateIt/pypi
    :target: https://github.com/BrightEdgeeServices/PythonTemplateIt/deployments/pypi
    :alt: GitHub - PiPy Deployment
